@@ -838,7 +838,7 @@ class LaharFlowData(object):
     
     def save_gtiff(self, fileIn, fileOut=None, crs=None, **kwargs):
 
-        self._validFile(fileIn)
+        self._valid_input_file(fileIn)
 
         raster = self.raster(fileIn, crs=crs)
 
